Index: trunk/ippMonitor/czartool/czartool/CzarDb.pm
===================================================================
--- trunk/ippMonitor/czartool/czartool/CzarDb.pm	(revision 38212)
+++ trunk/ippMonitor/czartool/czartool/CzarDb.pm	(revision 38213)
@@ -685,4 +685,6 @@
     $query->execute;
 
+    # print "fromTime: $fromTime, toTime: $toTime\n";
+
     # set up Gnuplot datafiles
     my $tmpFile = File::Temp->new( TEMPLATE => "czarplot_gnuplot_".$label."_".$stage."_t.XXXXX", DIR => '/tmp', SUFFIX => 'dat');
@@ -727,4 +729,6 @@
         my ($thisTimestamp, $thisPending, $thisFaults, $thisProcessed) = @row;
 
+        # print "$thisTimestamp, $thisPending, $thisFaults, $thisProcessed\n";
+
         $formattedTimestamp = $self->getFormattedDate($thisTimestamp);
 
@@ -743,7 +747,7 @@
 
             # First, look for large positive jumps in processed, most likely a label
             # added, and store value to subtract from linear value below. If > 1000
             # processed per hour, then it must be wrong
-            if (($thisProcessed - $lastProcessed)/($timeSep/3600) > 1000) {
+            if (($thisProcessed - $lastProcessed)/($timeSep/3600) > 5000) {
                 $positiveJump = $thisProcessed - $lastProcessed;
             }
@@ -763,4 +767,6 @@
                 $linearProcessed = $linearProcessed;
             }
+
+            # print "$thisTimestamp, $thisPending, $thisFaults, $thisProcessed, $timeSep, $diffProcessed, $linearProcessed\n";
 
             # calculate first derivative in units of images per hour
@@ -743,7 +747,7 @@
 
             # First, look for large positive jumps in processed, most likely a label
-            # added, and store value to subtract from linear value below. If > 1000
+            # added, and store value to subtract from linear value below. If > 5000
             # processed per hour, then it must be wrong
